@@ -1,4 +1,5 @@
 import os
+import traceback
 from requests import HTTPError, ConnectionError as RequestsConnectionError
 from tabulate import tabulate
 import click
@@ -60,25 +61,27 @@ def error_message_func(message):
     return lambda response=None: click.echo(click.style(message, fg='red'))
 
 
-def exception_message(exception):
+def exception_message(exception, debug_mode):
     """
         A helper function for creating error messages
         The function determines the message to show by the exception given
 
         Args:
             message (str): The message to show
+            debug_mode (bool): debug mode
 
         Returns: a function that outputs an error message
 
         """
-    click.echo(click.style(f"{get_error_message(exception)}", fg='red'))
+    click.echo(click.style(f"{get_error_message(exception, debug_mode)}", fg='red'))
 
 
-def get_error_message(exception):
+def get_error_message(exception, debug_mode):
     """
     Get a message for the given exception
     Args:
         exception (:obj:`Exception`): An exception
+        debug_mode (bool): debug mode
 
     Returns:
         A message for the user according to the exception
@@ -98,6 +101,10 @@ def get_error_message(exception):
         if exception.response.status_code == 400:
             return "Not logged in or bad request"
 
+    if debug_mode:
+        track = traceback.format_exc()
+        return track
+
     return 'Unknown'
 
 
