@@ -20,29 +20,26 @@ DAY = 24 * HOUR
 
 class JobStatus(enum.Enum):
     """Job statuses"""
-    unknown = 'Unknown'
-    listed = 'Listed'
-    working = 'Working'
-    stopped = 'Stopped'
+    created = 'Created'
+    queued = 'Queued'
+    running = 'Running'
     stopping = 'Stopping'
-    done = 'Done'
+    stopped = 'Stopped'
     failed = 'Failed'
-    deleted = 'Deleted'
+    success = 'Success'
 
 
-JOB_RUNNING_STATES = {JobStatus.listed, JobStatus.working}
-JOB_TERMINAL_STATES = {x for x in JobStatus if x not in JOB_RUNNING_STATES}
+JOB_TERMINAL_STATES = {JobStatus.stopping, JobStatus.stopped, JobStatus.failed, JobStatus.success}
 
 
 class TaskStatus(enum.Enum):
     """Task statuses"""
-    unknown = 'Unknown'
-    listed = 'Listed'
+    created = 'Created'
+    queued = 'Queued'
     running = 'Running'
     stopped = 'Stopped'
     success = 'Success'
     failed = 'Failed'
-    deleted = 'Deleted'
 
 
 class ClusterType(enum.Enum):
