@@ -9,9 +9,8 @@ from disco import Job
 from disco.core.exceptions import BucketPathsException, BucketPathsErrorTypes, RequestException, GraphQLRequestException
 from disco.core.constants import JobStatus, ClusterType
 from disco.task import TaskResult
-
 from .sdk_mocks import MockListJobsResponse, MockViewJobResponse, MockBadIdException, \
-    MockViewStoppedJobResponse, MockListTasksResponse
+    MockViewStoppedJobResponse, MockListTasksResponse, MockListTasksResponseNoInputFile
 from mock import patch, call
 from click.testing import CliRunner
 from disco_cli import cli, setup_cli
@@ -115,6 +114,23 @@ class TestJobCommands(BaseTest):
             assert output_message_includes(result, '| range01.txt | 5e4bef1942abec000cab2a71 | Success  | 00:00:17   '
                                                    '| 5e4beee087b4b2000edc6f2e |')
 
+    @patch('disco.gql.authentication.Authentication.is_logged_in')
+    def test_tasks_list_no_input_files(self, is_logged_in_mock):
+        """
+        Tests tasks list
+        """
+        is_logged_in_mock.return_value = True
+        with patch('disco.Job.get_tasks') as list_tasks_mock:
+            list_tasks_mock.return_value = MockListTasksResponseNoInputFile
+            runner = CliRunner()
+            result = runner.invoke(cli, ['job', 'tasks-list', 'job_id'])
+            print(result.output)
+            assert result.exit_code == 0
+            list_tasks_mock.assert_called()
+            is_logged_in_mock.assert_called()
+            assert output_message_includes(result, '| Task with no input | 5e4bef1942abec000cab2a71 | Success  '
+                                                   '| 00:00:17   |                |')
+
     @patch('disco.gql.authentication.Authentication.is_logged_in')
     @patch('disco.Job.create')
     @patch('pathlib.Path.exists')
